import { ElementRef } from '@angular/core';
import { IgxDaysViewComponent, CalendarView } from './days-view/days-view.component';
import { IgxYearsViewComponent } from './years-view/years-view.component';
import { IgxMonthsViewComponent } from './months-view/months-view.component';
import { ICalendarDate } from './calendar';
/**
 * **Ignite UI for Angular Calendar** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/calendar.html)
 *
 * The Ignite UI Calendar provides an easy way to display a calendar and allow users to select dates using single, multiple
 * or range selection.
 *
 * Example:
 * ```html
 * <igx-calendar selection="range"></igx-calendar>
 * ```
 */
export declare class IgxCalendarComponent extends IgxDaysViewComponent {
    elementRef: ElementRef;
    /**
     * Sets/gets the `id` of the calendar.
     * If not set, the `id` will have value `"igx-calendar-0"`.
     * ```html
     * <igx-calendar id = "my-first-calendar"></igx-calendar>
     * ```
     * ```typescript
     * let calendarId =  this.calendar.id;
     * ```
     * @memberof IgxCalendarComponent
     */
    id: string;
    /**
     * Gets whether the `day`, `month` and `year` should be rendered
     * according to the locale and formatOptions, if any.
     * ```typescript
     * let formatViews = this.calendar.formatViews;
     * ```
     */
    /**
    * Gets whether the `day`, `month` and `year` should be rendered
    * according to the locale and formatOptions, if any.
    * ```html
    * <igx-calendar [formatViews] = "{ day: true, month: false, year: true }"></igx-calendar>
    * ```
    * @memberof IgxCalendarComponent
    */
    formatViews: object;
    /**
     * Sets/gets whether the calendar header will be in vertical position.
     * Default value is `false`.
     * ```html
     * <igx-calendar [vertical] = "true"></igx-calendar>
     * ```
     * ```typescript
     * let isVertical = this.calendar.vertical;
     * ```
     */
    vertical: boolean;
    /**
     * The default `tabindex` attribute for the component.
     *
     * @hidden
     */
    tabindex: number;
    /**
     * The default aria role attribute for the component.
     *
     * @hidden
     */
    role: string;
    /**
     * The default aria lebelled by attribute for the component.
     *
     * @hidden
     */
    ariaLabelledBy: string;
    /**
     * The default css class applied to the component.
     *
     * @hidden
     */
    readonly styleVerticalClass: boolean;
    /**
     * @hidden
     */
    dacadeView: IgxYearsViewComponent;
    /**
     * @hidden
     */
    monthsView: IgxMonthsViewComponent;
    /**
     * @hidden
     */
    daysView: IgxDaysViewComponent;
    /**
     * @hidden
     */
    monthsBtn: ElementRef;
    /**
     * @hidden
     */
    yearsBtn: ElementRef;
    /**
     * @hidden
     */
    readonly isDefaultView: boolean;
    /**
     * @hidden
     */
    readonly isYearView: boolean;
    /**
     * @hidden
     */
    readonly isDecadeView: boolean;
    /**
     * Gets the current active view of the calendar.
     * ```typescript
     * let activeView =  this.calendar.activeView;
     * ```
     */
    /**
    * Sets the current active view of the calendar.
    * ```typescript
    * this.calendar.activeView = activeView;
    * ```
    */
    activeView: CalendarView;
    /**
     * @hidden
     */
    /**
    * @hidden
    */
    monthAction: string;
    /**
     * Gets the header template.
     * ```typescript
     * let headerTemplate =  this.calendar.headerTeamplate;
     * ```
     * @memberof IgxCalendarComponent
     */
    /**
    * Sets the header template.
    * ```html
    * <igx-calendar headerTemplateDirective = "igxCalendarHeader"></igx-calendar>
    * ```
    * @memberof IgxCalendarComponent
    */
    headerTemplate: any;
    /**
     * Gets the subheader template.
     * ```typescript
     * let subheaderTemplate = this.calendar.subheaderTemplate;
     * ```
     */
    /**
    * Sets the subheader template.
    * ```html
    * <igx-calendar subheaderTemplate = "igxCalendarSubheader"></igx-calendar>
    * ```
    * @memberof IgxCalendarComponent
    */
    subheaderTemplate: any;
    /**
     * Gets the context for the template marked with the `igxCalendarHeader` directive.
     * ```typescript
     * let headerContext =  this.calendar.headerContext;
     * ```
     */
    readonly headerContext: {
        $implicit: {
            date: Date;
            full: string;
            monthView: () => void;
            yearView: () => void;
        };
    };
    /**
     * Gets the context for the template marked with either `igxCalendarSubHeaderMonth`
     * or `igxCalendarSubHeaderYear` directive.
     * ```typescript
     * let context =  this.calendar.context;
     * ```
     */
    readonly context: {
        $implicit: {
            date: Date;
            full: string;
            monthView: () => void;
            yearView: () => void;
        };
    };
    /**
     * @hidden
     */
    readonly headerDate: Date;
    /**
     * @hidden
     */
    private headerTemplateDirective;
    /**
     * @hidden
     */
    private subheaderTemplateDirective;
    /**
     *@hidden
     */
    private _activeView;
    /**
     *@hidden
     */
    private _monthAction;
    /**
     *@hidden
     */
    private _formatViews;
    /**
     *@hidden
     */
    constructor(elementRef: ElementRef);
    /**
     * Returns the locale representation of the month in the month view if enabled,
     * otherwise returns the default `Date.getMonth()` value.
     *
     * @hidden
     */
    formattedMonth(value: Date): string;
    /**
     * Returns the locale representation of the year in the year view if enabled,
     * otherwise returns the default `Date.getFullYear()` value.
     *
     * @hidden
     */
    formattedYear(value: Date): string;
    /**
     * @hidden
     */
    previousMonth(isKeydownTrigger?: boolean): void;
    /**
     * @hidden
     */
    previousMonthKB(event: any): void;
    /**
     * @hidden
     */
    nextMonth(isKeydownTrigger?: boolean): void;
    /**
     * @hidden
     */
    nextMonthKB(event: any): void;
    /**
     * @hidden
     */
    previousYear(): void;
    /**
     * @hidden
     */
    nextYear(): void;
    /**
     * @hidden
     */
    getFormattedDate(): {
        weekday: string;
        monthday: string;
    };
    /**
     * @hidden
     */
    childClicked(instance: ICalendarDate): void;
    /**
     * @hidden
     */
    viewChanged(event: any): void;
    /**
     * @hidden
     */
    changeYear(event: Date): void;
    /**
     * @hidden
     */
    changeMonth(event: Date): void;
    /**
     * @hidden
     */
    activeViewYear(): void;
    /**
     * @hidden
     */
    activeViewYearKB(event: any): void;
    /**
     * @hidden
     */
    activeViewDecade(): void;
    /**
     * @hidden
     */
    activeViewDecadeKB(event: any): void;
    /**
     * Deselects date(s) (based on the selection type).
     *```typescript
     * this.calendar.deselectDate(new Date(`2018-06-12`));
     *````
     */
    deselectDate(value?: Date | Date[]): void;
    /**
     * @hidden
     */
    onKeydownPageUp(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownPageDown(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownShiftPageUp(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownShiftPageDown(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownHome(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownEnd(event: KeyboardEvent): void;
    /**
     * Helper method building and returning the context object inside
     * the calendar templates.
     * @hidden
     */
    private generateContext;
}
